# Generated by Django 4.2.3 on 2023-07-17 10:33

from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name='Chronopost',
            fields=[
                (
                    'id',
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name='ID'
                    ),
                ),
                ('name', models.CharField(max_length=255, verbose_name='Tour Name')),
                ('date', models.DateField(verbose_name='Tour Date')),
                ('charged_packages', models.IntegerField(verbose_name='Charged Packages')),
                ('charged_points', models.IntegerField(verbose_name='Charged Points')),
                ('including_ip', models.IntegerField(verbose_name='Including IP')),
                ('relay', models.IntegerField(verbose_name='Relay')),
                ('return_packages', models.IntegerField(verbose_name='Return Packages')),
                ('return_points', models.IntegerField(verbose_name='Return Points')),
                ('overdue', models.IntegerField(verbose_name='Overdue')),
                ('anomalies', models.IntegerField(verbose_name='Anomalies')),
                ('total_points', models.IntegerField(verbose_name='Total Points')),
                ('hours', models.IntegerField(verbose_name='Hours')),
                ('breaks', models.IntegerField(verbose_name='Breaks')),
                ('full_km', models.IntegerField(verbose_name='Full KM')),
            ],
            options={
                'verbose_name': 'Chronopost',
                'verbose_name_plural': 'Chronopost',
            },
        ),
        migrations.CreateModel(
            name='Ciblex',
            fields=[
                (
                    'id',
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name='ID'
                    ),
                ),
                ('name', models.CharField(max_length=255, verbose_name='Tour Name')),
                ('type', models.CharField(default='LIVRAISONS', max_length=255)),
                (
                    'code',
                    models.CharField(
                        choices=[
                            ('35011', '35011 - RENNES SUD'),
                            ('35020', '35020 - RENNES CHU'),
                            ('35022', '35022 - MONTFORT SUR MEU'),
                            ('35023', '35023 - PACE - ZI LORIENT'),
                        ],
                        max_length=5,
                    ),
                ),
                ('date', models.DateField(verbose_name='Tour Date')),
                ('nights', models.IntegerField(verbose_name='nights')),
                ('days', models.IntegerField(verbose_name='days')),
                ('avp', models.IntegerField(verbose_name='avp')),
                ('spare_part', models.IntegerField(verbose_name='spare part')),
                ('synchro', models.IntegerField(verbose_name='synchro')),
                ('morning_pickup', models.IntegerField(verbose_name='morning pickups')),
            ],
            options={
                'verbose_name': 'Ciblex',
                'verbose_name_plural': 'Ciblex',
            },
        ),
        migrations.CreateModel(
            name='GLS',
            fields=[
                (
                    'id',
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name='ID'
                    ),
                ),
                ('name', models.CharField(max_length=255, verbose_name='Tour Name')),
                ('date', models.DateField(verbose_name='Tour Date')),
                ('points_charges', models.IntegerField(verbose_name='Points Charges')),
                ('points_delivered', models.IntegerField(verbose_name='Points Delivered')),
                ('packages_charges', models.IntegerField(verbose_name='Packages Charges')),
                ('packages_delivered', models.IntegerField(verbose_name='Packages Delivered')),
                ('avp_relay', models.IntegerField(verbose_name='AVP Relay')),
                ('shd', models.IntegerField(verbose_name='SHD')),
                ('eo', models.IntegerField(verbose_name='EO')),
                ('pickup_point', models.IntegerField(verbose_name='Pickup Point')),
            ],
            options={
                'verbose_name': 'GLS',
                'verbose_name_plural': 'GLS',
            },
        ),
        migrations.CreateModel(
            name='TNT',
            fields=[
                (
                    'id',
                    models.BigAutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name='ID'
                    ),
                ),
                ('name', models.CharField(max_length=255, verbose_name='Tour Name')),
                ('date', models.DateField(verbose_name='Tour Date')),
                ('client_numbers', models.IntegerField(verbose_name='Client numbers')),
                ('refused', models.IntegerField(verbose_name='Refused')),
                ('avp', models.IntegerField(verbose_name='avp')),
                ('cad', models.IntegerField(verbose_name='cad/return')),
                ('totals_clients', models.IntegerField(verbose_name='totals clients')),
                (
                    'occasional_abductions',
                    models.IntegerField(verbose_name='occasional abductions'),
                ),
                ('regular_abductions', models.IntegerField(verbose_name='regular abductions')),
                (
                    'totals_clients_abductions',
                    models.IntegerField(verbose_name='total clients abductions'),
                ),
                ('hours', models.IntegerField(verbose_name='hours')),
                ('breaks', models.IntegerField(verbose_name='breaks')),
                ('kilometers', models.IntegerField(verbose_name='KM/Full')),
            ],
            options={
                'verbose_name': 'TNT - Fedex',
                'verbose_name_plural': 'TNT - Fedex',
            },
        ),
    ]
